PdfPage class abstract

Handles a PDF page in PdfDocument.

See PdfDocument.pages.

Available extensions

Constructors

PdfPage()

Properties

document PdfDocument
PDF document.
no setter
events Stream<PdfPageStatusChange>

Available on PdfPage, provided by the PdfPageBaseExtensions extension

Stream of page status change events for this page.
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
PDF page height in points (height in pixels at 72 dpi) (rotated).
no setter
isLoaded bool
Whether the page is really loaded or not.
no setter
latestPageStream Stream<PdfPage>

Available on PdfPage, provided by the PdfPageBaseExtensions extension

Stream of latest page instances when the page status changes.
no setter
pageNumber int
Page number. The first page is 1.
no setter
rotation PdfPageRotation
PDF page rotation.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
PDF page width in points (width in pixels at 72 dpi) (rotated).
no setter

Methods

createCancellationToken() PdfPageRenderCancellationToken
Create PdfPageRenderCancellationToken to cancel the rendering process.
ensureLoaded() Future<PdfPage>

Available on PdfPage, provided by the PdfPageBaseExtensions extension

Ensure the page is really loaded.
Load links.
loadStructuredText({bool ensureLoaded = true}) Future<PdfPageText>

Available on PdfPage, provided by the PdfPageBaseExtensions extension

Load structured text with character bounding boxes.
loadText() Future<PdfPageRawText?>
Load plain text for the page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({int x = 0, int y = 0, int? width, int? height, double? fullWidth, double? fullHeight, int? backgroundColor, PdfPageRotation? rotationOverride, PdfAnnotationRenderingMode annotationRenderingMode = PdfAnnotationRenderingMode.annotationAndForms, int flags = PdfPageRenderFlags.none, PdfPageRenderCancellationToken? cancellationToken}) Future<PdfImage?>
Render a sub-area or full image of specified PDF file. Returned image should be disposed after use. x, y, width, height specify sub-area to render in pixels. fullWidth, fullHeight specify virtual full size of the page to render in pixels.
rotated180() PdfPage

Available on PdfPage, provided by the PdfPageWithRotationExtension extension

Rotates a page clockwise by 180 degrees.
rotatedBy(PdfPageRotation delta) PdfPage

Available on PdfPage, provided by the PdfPageWithRotationExtension extension

Rotates a page with rotation added to the current rotation.
rotatedCCW90() PdfPage

Available on PdfPage, provided by the PdfPageWithRotationExtension extension

Rotates a page counter-clockwise by 90 degrees.
rotatedCW90() PdfPage

Available on PdfPage, provided by the PdfPageWithRotationExtension extension

Rotates a page clockwise by 90 degrees.
rotatedTo(PdfPageRotation rotation) PdfPage

Available on PdfPage, provided by the PdfPageWithRotationExtension extension

Rotates a page with the specified rotation.
toString() String
A string representation of this object.
inherited
waitForLoaded({Duration? timeout}) Future<PdfPage?>

Available on PdfPage, provided by the PdfPageBaseExtensions extension

Wait until the page is really loaded.
withPageNumber(int pageNumber) PdfPage

Available on PdfPage, provided by the PdfPageRenumberedExtension extension

Renumbers a page with the specified page number.

Operators

operator ==(Object other) bool
The equality operator.
inherited