loadLinks abstract method
Load links.
Results may be cached for this page instance. Reload the page after modifying its annotations.
If compact is true, the link data may be compacted. Cached implementations may return compact data for both
values to avoid retaining duplicate results. See PdfLink.compact for more info.
If enableAutoLinkDetection is true, the function tries to detect Web links automatically.
This is useful if the PDF file contains text that looks like Web links but not defined as links in the PDF.
The default is true.
If the page is not loaded yet (progressive loading case only), this function returns an empty list.
Implementation
Future<List<PdfLink>> loadLinks({bool compact = false, bool enableAutoLinkDetection = true});