PdfDocumentLoadCompleteEvent class
Event that is triggered when the PDF document has finished loading.
- Implemented types
Constructors
- PdfDocumentLoadCompleteEvent(PdfDocument document)
-
const
Properties
- document → PdfDocument
-
Document that this event is related to.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PdfDocumentEventType
-
Event type.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited