PdfDocumentMissingFontsEvent class

Event that is triggered when the list of missing fonts in the PDF document has changed.

Implemented types

Constructors

PdfDocumentMissingFontsEvent(PdfDocument document, List<PdfFontQuery> missingFonts)
Create a PdfDocumentMissingFontsEvent.
const

Properties

document PdfDocument
Document that this event is related to.
final
hashCode int
The hash code for this object.
no setterinherited
missingFonts List<PdfFontQuery>
The list of missing fonts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PdfDocumentEventType
Event type.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited